@@ -440,6 +440,13 @@ class GenerateQuantitiesTest(CustomTestCase):
 
         self.assertEqual(fit.stan_variable('zs').shape, (10, 2, 3))
         self.assertEqual(fit.stan_variable('z')[0], 3 + 4j)
+
+        self.assertTrue(
+            np.allclose(
+                fit.stan_variable('zs')[0], np.array([[3, 4j, 5], [1j, 2j, 3j]])
+            )
+        )
+
         # make sure the name 'imag' isn't magic
         self.assertEqual(fit.stan_variable('imag').shape, (10, 2))
 
