@@ -258,6 +258,13 @@ class VariationalTest(unittest.TestCase):
 
         self.assertEqual(fit.stan_variable('zs').shape, (2, 3))
         self.assertEqual(fit.stan_variable('z'), 3 + 4j)
+
+        self.assertTrue(
+            np.allclose(
+                fit.stan_variable('zs'), np.array([[3, 4j, 5], [1j, 2j, 3j]])
+            )
+        )
+
         # make sure the name 'imag' isn't magic
         self.assertEqual(fit.stan_variable('imag').shape, (2,))
 
